==> Greenstone-3.12-candidate-2025.07.16-source-distribution.zip: Greenstone-3.12-source-distribution/ext-cli/get-selfcontained-jdk.sh <==
#!/bin/bash

OS_ALLCAPS=`uname -s | sed 's/_.*$//' | tr 'a-z' 'A-Z'`

selfcon_ext=selfcontained-jdk
installed_dir=${selfcon_ext}/zulu-jdk11-64bit

echo ""
if [ ! -d $selfcon_ext ] ; then
    echo "Checking out from svn: Greenstone3's $selfcon_ext extension"
    svn co https://svn.greenstone.org/gs3-extensions/$selfcon_ext/trunk $selfcon_ext

    if [ $? != 0 ] ; then
	echo "Error encountered checking out: " 1>&2
	echo "    svn co https://svn.greenstone.org/gs3-extensions/$selfcon_ext/trunk $selfcon_ext" 1>&2
	exit 1
    fi
else
    echo "Detected directory '$selfcon_ext'"
    echo "=> Taken to mean that the svn check-out command has already been run"
fi

echo ""
if [ ! -d $installed_dir ] ; then
    echo "Runing the $selfcon_ext/PREPARE-${OS_ALLCAPS}.sh"

    cd $selfcon_ext && ./PREPARE-${OS_ALLCAPS}.sh

    if [ $? != 0 ] ; then
	echo "Error encountered running: " 1>&2
	echo "        cd $selfcon_ext && ./PREPARE-${OS_ALLCAPS}.sh" 1>&2
	exit 1
    fi
	
else
    echo "Detected directory '$installed_dir'"
    echo "=> Taken to mean that the $selfcon_ext/PREPARE-${OS_ALLCAPS}.sh command has already been run"    
fi


if [ "x$JAVA_HOME" != "x$PWD/$installed_dir" ] ; then
    echo ""
    echo "To use this installed version of JDK, in the top-level Greenstone3 directory run:"
    echo "    source ./gs3-setup-cli.sh"
    echo ""
else
    echo ""
    echo "Detected JAVA_HOME set to \$PWD/$installed_dir"
    echo "=> Taken to mean that the $selfcon_ext SETUP.sh file has been sourced"
fi

echo ""

==> Greenstone-3.13-candidate-2025.12.05-source-distribution.zip: Greenstone-3.13-source-distribution/ext-cli/get-selfcontained-jdk.sh <==
#!/bin/bash

OS_ALLCAPS=`uname -s | sed 's/_.*$//' | tr 'a-z' 'A-Z'`

selfcon_ext=selfcontained-jdk
installed_dir=${selfcon_ext}/zulu-jdk11-64bit

echo ""
if [ ! -d $selfcon_ext ] ; then
    echo "Checking out from svn: Greenstone3's $selfcon_ext extension"
    svn co https://svn.greenstone.org/gs3-extensions/$selfcon_ext/trunk $selfcon_ext

    if [ $? != 0 ] ; then
	echo "Error encountered checking out: " 1>&2
	echo "    svn co https://svn.greenstone.org/gs3-extensions/$selfcon_ext/trunk $selfcon_ext" 1>&2
	exit 1
    fi
else
    echo "Detected directory '$selfcon_ext'"
    echo "=> Taken to mean that the svn check-out command has already been run"
fi

echo ""
if [ ! -d $installed_dir ] ; then
    echo "Runing the $selfcon_ext/PREPARE-${OS_ALLCAPS}.sh"

    cd $selfcon_ext && ./PREPARE-${OS_ALLCAPS}.sh

    if [ $? != 0 ] ; then
	echo "Error encountered running: " 1>&2
	echo "        cd $selfcon_ext && ./PREPARE-${OS_ALLCAPS}.sh" 1>&2
	exit 1
    fi
	
else
    echo "Detected directory '$installed_dir'"
    echo "=> Taken to mean that the $selfcon_ext/PREPARE-${OS_ALLCAPS}.sh command has already been run"    
fi


if [ "x$JAVA_HOME" != "x$PWD/$installed_dir" ] ; then
    echo ""
    echo "To use this installed version of JDK, run "
    echo "    source ./SETUP-CLI.sh "
    echo "in the ext-cli folder."
    echo ""
else
    echo ""
    echo "Detected JAVA_HOME set to \$PWD/$installed_dir"
    echo "=> Taken to mean that the $selfcon_ext SETUP.sh file has been sourced"
fi

echo ""
